<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0"
xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
xmlns:xsd="http://www.w3.org/2001/XMLSchema"
xmlns:xforms="http://www.w3.org/2002/xforms"
xmlns:dom="http://www.w3.org/2001/xml-events"
xmlns:oooc="http://openoffice.org/2004/calc"
xmlns:ooow="http://openoffice.org/2004/writer"
xmlns:ooo="http://openoffice.org/2004/office"
xmlns:script="urn:oasis:names:tc:opendocument:xmlns:script:1.0"
xmlns:form="urn:oasis:names:tc:opendocument:xmlns:form:1.0"
xmlns:math="http://www.w3.org/1998/Math/MathML"
xmlns:dr3d="urn:oasis:names:tc:opendocument:xmlns:dr3d:1.0"
xmlns:chart="urn:oasis:names:tc:opendocument:xmlns:chart:1.0"
xmlns:svg="urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0"
xmlns:number="urn:oasis:names:tc:opendocument:xmlns:datastyle:1.0"
xmlns:meta="urn:oasis:names:tc:opendocument:xmlns:meta:1.0"
xmlns:dc="http://purl.org/dc/elements/1.1/"
xmlns:xlink="http://www.w3.org/1999/xlink"
xmlns:fo="urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0"
xmlns:draw="urn:oasis:names:tc:opendocument:xmlns:drawing:1.0"
xmlns:table="urn:oasis:names:tc:opendocument:xmlns:table:1.0"
xmlns:text="urn:oasis:names:tc:opendocument:xmlns:text:1.0"
xmlns:style="urn:oasis:names:tc:opendocument:xmlns:style:1.0"
version="1.0">
  <!--  <xsl:output method="html" version="4.0" encoding="UTF-8" indent="yes" /> -->
  <xsl:output method="xml" encoding="UTF-8" indent="yes" />

  <!-- This key is used as part of a trick way to output several style definitions once for each UNIQUE font attribute
	 that occurs in a language element -->
  <xsl:key name="distinct-font" match="language" use="@font"/>
  <xsl:template match="document">
    <office:document-content office:version="1.0">
		- <office:automatic-styles>
			- <style:style style:name="fr1" style:family="graphic" style:parent-style-name="Frame">
          <style:graphic-properties fo:margin-left="0in" fo:margin-right="0.05in" style:vertical-pos="top" style:vertical-rel="baseline" fo:padding="0in" fo:border="none" style:shadow="none" />
        </style:style>
        <text:list-style style:name="L1">
          <text:list-level-style-number text:level="1" text:style-name="Numbering_20_Symbols" style:num-suffix="." style:num-format="1">
            <style:list-level-properties text:list-level-position-and-space-mode="label-alignment">
              <style:list-level-label-alignment text:label-followed-by="listtab" text:list-tab-stop-position="1.376cm" fo:text-indent="-0.635cm" fo:margin-left="1.376cm"/>
            </style:list-level-properties>
          </text:list-level-style-number>
        </text:list-style>
      </office:automatic-styles>
      <office:body>
        <office:text>
          <xsl:apply-templates/>
        </office:text>
      </office:body>
    </office:document-content>
  </xsl:template>
  
  <!-- These keys are used to determine which lines are present in the interlinear, 
       in part so that missing glosses can be detected and a placeholder can be inserted instead -->
  <xsl:key name="itemTypes" match="//item" use="@type"/>
  <xsl:key name="items" match="//item" use="concat(@type, '/', @lang)"/>
  <xsl:variable name="lines" >
    <xsl:for-each select="//item[generate-id()=
          generate-id(key('itemTypes', @type)[1])]">
          <xsl:variable name="currentType" select="@type"/>
          <xsl:for-each select="//item[generate-id()=
            generate-id(key('items', concat($currentType, '/', @lang))[1])]">
            <item>
                <xsl:attribute name="type"><xsl:value-of select="@type" />
                </xsl:attribute>
                <xsl:attribute name="lang"><xsl:value-of select="@lang" />
                </xsl:attribute>
            </item>
          </xsl:for-each>
    </xsl:for-each>
  </xsl:variable>
  <xsl:variable name="placeholder" select="'???'" />
  

  <!-- INTERLINEAR-TEXT LEVEL -->

  <xsl:template match="interlinear-text">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="interlinear-text/item">
    <text:p text:style-name="Default">
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>

  <xsl:template match="interlinear-text/item[@type='title']">
    <text:p text:style-name="Interlin_Title">
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>
  <xsl:template match="interlinear-text/item[@type='title-abbreviation']"/>
  <xsl:template match="interlinear-text/item[@type='source']">
    <text:p text:style-name="Interlin_Source">
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>

  <!-- PARAGRAPH LEVEL -->

  <xsl:template match="paragraphs">
    <text:list text:style-name="Numbering_20_1" xml:id="list7088686064535947017">
      <xsl:apply-templates/>
    </text:list>
  </xsl:template>

  <xsl:template match="paragraph">
    <xsl:apply-templates/>
  </xsl:template>

  <!-- PHRASE LEVEL -->

  <xsl:template match="phrases">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="phrase">

    <!-- <text:p text:style-name="Interlin_Words"> -->
    <!-- <draw:frame text:anchor-type="as-char" draw:style-name="Interlin_Frame_Number" fo:min-width="0.1402in"> -->
    <!-- <xsl:attribute name="draw:name">FrameN<xsl:number level="any"/> -->
    <!-- </xsl:attribute> -->
    <!-- <xsl:attribute name="draw:z-index"> -->
    <!-- <xsl:number level="any" count="item"/> -->
    <!-- </xsl:attribute> -->
    <!-- <draw:text-box fo:min-height="0.1402in"> -->
    <!-- <xsl:if test="item[@type='segnum']"> -->
    <!-- <text:p text:style-name="Interlin_Phrase_Number"> -->
    <!-- <xsl:value-of select="item[@type='segnum']"/> -->
    <!-- </text:p> -->
    <!-- </xsl:if> -->
    <!-- </draw:text-box> -->
    <!-- </draw:frame> -->
    <text:list-item>
      <text:p>
        <xsl:attribute name="text:style-name">Interlin_Baseline_NoFrame</xsl:attribute>
        <xsl:apply-templates mode="words"/>
        <!-- </text:p> -->
      </text:p>
      <xsl:apply-templates mode="items"/>
    </text:list-item>
  </xsl:template>

  <xsl:template match="phrase/item" mode="items">
    <!-- freeform in its own paragraph -->
    <xsl:if test="@type!='segnum'">
      <text:p>
        <xsl:attribute name="text:style-name">Interlin_Freeform_Gloss_<xsl:value-of select="@lang"/>
        </xsl:attribute>
        <xsl:apply-templates/>
      </text:p>
    </xsl:if>
  </xsl:template>

  <xsl:template match="*" mode="items">
  </xsl:template>

  <!-- WORD LEVEL -->

  <xsl:template match="words" mode="words">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="*" mode="words">
  </xsl:template>

  <xsl:template match="word[not(item[@type='punct'])]">

    <draw:frame text:anchor-type="as-char" draw:style-name="Interlin_Frame_Word" fo:min-width="0.1402in">
      <xsl:attribute name="draw:name">FrameW<xsl:number level="any"/>
      </xsl:attribute>
      <xsl:attribute name="draw:z-index">
        <xsl:number level="any" count="item"/>
      </xsl:attribute>
      <draw:text-box fo:min-height="0.1402in">
        <xsl:apply-templates/>
      </draw:text-box>
    </draw:frame>
  </xsl:template>

  <xsl:template match="word/item[@type='txt']">
    <text:p>
      <!-- <xsl:attribute name="text:style-name">Interlin_Base_<xsl:value-of select="@lang"/></xsl:attribute> -->
      <!-- common style for the first line of the interlinear -->
      <xsl:attribute name="text:style-name">Interlin_Baseline</xsl:attribute>
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>

  <xsl:template match="word/item[@type='punct']">

    <text:span>
      <xsl:value-of select="current()" />
    </text:span>

  </xsl:template>

  <xsl:template match="word/item[@type='gls']">
    <text:p>
      <xsl:attribute name="text:style-name">Interlin_Word_Gloss_<xsl:value-of select="@lang"/>
      </xsl:attribute>
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>

  <xsl:template match="word/item[@type='pos']">
    <text:p text:style-name="Interlin_Word_POS">
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>

  <!-- MORPHEME LEVEL -->

  <xsl:template match="morphemes">
    <!-- <text:p text:style-name="Interlin_Morphemes"> -->
    <xsl:if test="morph/item[@type='txt']">
      <text:p>
        <xsl:choose>
          <xsl:when test="count(preceding-sibling::*) = 0">	
            <!-- common style for the first line of the interlinear -->
            <xsl:attribute name="text:style-name">Interlin_Baseline</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="text:style-name">Interlin_Morph_<xsl:value-of select="morph/item[@type='txt']/@lang"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:for-each select="morph/item[@type='txt']">
          <xsl:value-of select="current()" />	
        </xsl:for-each>
      </text:p>		
    </xsl:if>

    <xsl:if test="morph/item[@type='cf']">		
      <text:p>
        <xsl:choose>
          <xsl:when test="count(preceding-sibling::*) = 0">	
            <!-- common style for the first line of the interlinear -->
            <xsl:attribute name="text:style-name">Interlin_Baseline</xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="text:style-name">Interlin_Cf_<xsl:value-of select="morph/item[@type='cf']/@lang"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:for-each select="morph/item[@type='cf']">
          <xsl:value-of select="current()" />	
        </xsl:for-each>
      </text:p>
    </xsl:if>

    <xsl:if test="morph/item[@type='msa']">	
      <text:p>
        <xsl:attribute name="text:style-name">Interlin_Morpheme_POS</xsl:attribute>
        <xsl:for-each select="morph">
          <xsl:if test="@type='suffix'">-</xsl:if>
          <xsl:if test="@type='infix'">&lt;</xsl:if>
          <xsl:value-of select="item[@type='msa']"/>
          <xsl:if test="@type='infix'">&gt;</xsl:if>
          <xsl:if test="@type='prefix'">-</xsl:if>
        </xsl:for-each>
        <!-- if the expected gloss is missing, insert questions marks -->
        <xsl:if test="not(morph/item[@type='msa'])">???</xsl:if>
      </text:p>
    </xsl:if>

    <xsl:if test="$gls_lang">	
      <text:p>
        <xsl:attribute name="text:style-name">Interlin_Morpheme_Gloss_<xsl:value-of select="$gls_lang"/>
        </xsl:attribute>

        <xsl:for-each select="morph">
          <xsl:if test="@type='suffix'">-</xsl:if>
          <xsl:if test="@type='infix'">&lt;</xsl:if>
          <xsl:value-of select="item[@type='gls']"/>
          <xsl:if test="@type='infix'">&gt;</xsl:if>
          <xsl:if test="@type='prefix'">-</xsl:if>
        </xsl:for-each>

        <!-- if the expected gloss is missing, insert questions marks -->
        <xsl:if test="not(morph/item[@type='gls'])">???</xsl:if>
      </text:p>      
    </xsl:if>		
 
    <!-- </text:p> -->
  </xsl:template>

  <xsl:template match="morph">
    <draw:frame text:anchor-type="as-char" draw:style-name="Interlin_Frame_Morpheme" fo:min-width="0.1402in">
      <xsl:attribute name="draw:name">FrameM<xsl:number level="any"/>
      </xsl:attribute>
      <xsl:attribute name="draw:z-index">
        <xsl:number level="any" count="item"/>
      </xsl:attribute>
      <draw:text-box fo:min-height="0.1402in">
        <xsl:apply-templates mode="rowItems"/>
      </draw:text-box>
    </draw:frame>
  </xsl:template>

  <xsl:template match="item[@type!='hn' and @type!='variantTypes' and @type!='glsAppend']" mode="rowItems">
    <text:p>
      <xsl:if test="@type='txt'">
        <xsl:attribute name="text:style-name">Interlin_Morph_<xsl:value-of select="@lang"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:if test="@type='cf'">
        <xsl:attribute name="text:style-name">Interlin_Cf_<xsl:value-of select="@lang"/>
        </xsl:attribute>
      </xsl:if>
      <xsl:if test="@type='msa'">
        <xsl:attribute name="text:style-name">Interlin_Morpheme_POS</xsl:attribute>
      </xsl:if>
      <xsl:apply-templates/>
    </text:p>
  </xsl:template>

  <xsl:template match="*" mode="rowItems">
  </xsl:template>
  <xsl:template match="*" mode="rows">
  </xsl:template>

  <!-- suppress homograph numbers in normal mode, so they don't occupy an extra line-->
  <xsl:template match="morph/item[@type='hn']">
  </xsl:template>
  <xsl:template match="morph/item[@type='variantTypes']">
  </xsl:template>
  <xsl:template match="morph/item[@type='glsAppend']">
  </xsl:template>

  <!-- This mode occurs within the 'cf' item to display the homograph number from the following item.-->
  <xsl:template match="morph/item[@type='hn']" mode="hn">
    <text:span text:style-name="Interlin_Homograph">
      <xsl:apply-templates/>
    </text:span>
  </xsl:template>
  <xsl:template match="morph/item[@type='variantTypes']" mode="variantTypes">
    <text:span text:style-name="Interlin_VariantTypes">
      <xsl:apply-templates/>
    </text:span>
  </xsl:template>
  <xsl:template match="morph/item[@type='glsAppend']" mode="glsAppend">
    <text:span text:style-name="Interlin_VariantTypes">
      <xsl:apply-templates/>
    </text:span>
  </xsl:template>

  <xsl:template match="morph/item[@type='cf']" mode="rowItems">
    <text:p>
      <xsl:attribute name="text:style-name">Interlin_Cf_<xsl:value-of select="@lang"/>
      </xsl:attribute>
      <xsl:apply-templates/>
      <xsl:variable name="homographNumber" select="following-sibling::item[1][@type='hn']"/>
      <xsl:if test="$homographNumber">
        <!-- todo: make a subscript with a rPr element-->
        <xsl:apply-templates select="$homographNumber" mode="hn"/>
      </xsl:if>
      <xsl:variable name="variantTypes" select="following-sibling::item[(count($homographNumber)+1)][@type='variantTypes']"/>
      <xsl:if test="$variantTypes">
        <xsl:apply-templates select="$variantTypes" mode="variantTypes"/>
      </xsl:if>
    </text:p>
  </xsl:template>

  <xsl:template match="morph/item[@type='gls']" mode="rowItems">
    <text:p>
      <xsl:attribute name="text:style-name">Interlin_Morpheme_Gloss_<xsl:value-of select="@lang"/>
      </xsl:attribute>
      <xsl:apply-templates/>
      <xsl:variable name="glsAppend" select="following-sibling::item[1][@type='glsAppend']"/>
      <xsl:if test="$glsAppend">
        <xsl:apply-templates select="$glsAppend" mode="glsAppend"/>
      </xsl:if>
    </text:p>
  </xsl:template>

  <!-- MISCELLANEOUS -->

</xsl:stylesheet>
